==> bacula-docs-1.38.5.tar.gz: bacula-docs-1.38.5/home-page/pages/makedonation.php <==

<? require_once("inc/header.php"); ?>

<form name="_xclick" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_xclick">
<input type="hidden" name="business" value="projects@bacula.org">
<input type="hidden" name="tax" value="0">
<input type="hidden" name="bn" value="PP-DonationsBF">
<input type="image" src="http://www.paypal.com/en_US/i/btn/x-click-butcc-donate.gif" border="0" name="submit" alt="Make payments with PayPal - it's fast, free and secure!">
</form>

<table>
<tr>
        <td class="contentTopic">
        Contributing to the Bacula Project
        </td>
</tr>
<tr>
    <td class="content">
    Although one talks about Free Software, in fact, software such
    as Bacula was not developed without some cost. The software
    may be free for the user, but it wasn't free for the developer
    or developers, either in terms of time or in terms of financial
    cost.

    For example, since beginning work on the Bacula project in
    January 2000 until now (October 2005), I (Kern) have spent
    approximately $8000 per year for computers, tape drives,
    communications expenses, electricity, software licenses, and
    other expenses.  I am not complaining and am pleased to have
    been able to afford these expenditures.  In addition, have no
    desire to have them reimbursed.

    Bacula is now a fairly mature product, and to ensure its long
    term survival, I believe it should start to pay its own way.
    <p>
    There are multiple ways of contributing to the Bacula
    project, some of which are: ideas, user support,
    documentation review, translation, programming and
    contributing code, testing the new releases, hosting
    services, testing machines, donating needed equipment, and
    financial support.

    Previously all but the last one were possible.
    It is now possible for you to contribute financial aid
    the Bacula project.  All funds collected will be used to help
    further the Bacula project by covering out of pocket expenses
    incurred by the project (no salaries).  Examples are,
    hardware, software licenses (yes Micro$oft), and possibly a
    portion of travel/conference expenses.

    <p>
    The project actually has the following needs (approximate costs): <br>
    Three Microsoft Visual C++ licenses:  $3000<br>
    Autochanger for FreeBSD testing:      $3200<br>
    Autochanger for Solaris testing:      $3200<br>

    If you have licenses or equipment to donate, please don't 
    hesitate to let me (Kern) know.  You may also provide financial     
    support for these items.

      
    <p>
    Contributions may not be US tax deductible as this is a individual
    Bacula project account with PayPal. 
    <p>
    If you are a government or for-profit corporation and cannot
    make &quot;donations&quot;, please consider paying a (non-obligatory)
    binary license fee for any Bacula built binaries that you download. 
    By providing you with these pre-built, pre-tested binaries, we are
    really providing you with an extra service, which merits you
    careful consideration for making a contribution or paying a 
    &quot;license fee&quot;.

    A reasonable license fee would be:
    <p>
    <table>
    <tr> <td>Number of Machines</td> <td>Fee</td></tr>
    <tr> <td>1-10</td>  <td>$10 per machine</td></tr>
    <tr> <td>11-20</td> <td>$100 + $5.00 per machine over 10</td></tr>
    <tr> <td>21-50</td> <td>$150 + $2.00 per machine over 20</td></tr>
    <tr> <td>51-...</td> <td>$250 + $1.00 per machine over 50</td></tr>
    </table>
    <p>Example: 55 machines = $250 + 5 X $1.00 = $255<br>
    <p>Upgrades are 10% of the original license fee.
    <p>
    The above table is just a suggestion. You are, of course, free
    to make a larger or smaller contribution as you see fit.

    If you wish your payment to be anonymous, please put the word
    ANONYMOUS in the &quot;Payment For:&quot; field on the PayPal      
    payment form.

    <p>
    To make a contribution, please click on the donate button at
    the top of the screen, and your transaction will be secured
    and confirmed directly by PayPal.  If you contribute, or have
    any questions, please send me an email directly: kern at
    sibbald dot com.

    <p>
    If you need an invoice, I can send you one, but in order to limit my
    administrative work, I kindly request you to make a donation of at least
    $200 before requesting an invoice. To obtain one, simply email me the exact
    name to appear on the invoice as well as the mailing address, the amount
    you want to contribute, and the project you are supporting (or simply
    Bacula development).
                                    

<p>
To see the donations made to date, please click on the 
Donations Received menu item to the left of your screen.
<p>
</tr>

</table>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-2.0.1.tar.gz: bacula-docs-2.0.1/home-page/pages/makedonation.php <==

<? require_once("inc/header.php"); ?>

<form name="_xclick" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_xclick">
<input type="hidden" name="business" value="projects@bacula.org">
<input type="hidden" name="tax" value="0">
<input type="hidden" name="bn" value="PP-DonationsBF">
<input type="image" src="http://www.paypal.com/en_US/i/btn/x-click-butcc-donate.gif" border="0" name="submit" alt="Make payments with PayPal - it's fast, free and secure!">
</form>

<table>
<tr>
        <td class="contentTopic">
        Contributing to the Bacula Project
        </td>
</tr>
<tr>
    <td class="content">
    Although one talks about Free Software, in fact, Open Software such
    as Bacula was not developed without some cost. The software
    may be free for the user, but it wasn't free for the developer
    or developers, either in terms of time or in terms of financial
    cost.

    For example, since beginning work on the Bacula project in
    January 2000 until now (August 2006), I (Kern) have spent
    approximately $8000 per year for computers, tape drives,
    communications expenses, electricity, software licenses, and
    other expenses.  I am not complaining and am pleased to have
    been able to afford these expenditures.  In addition, have no
    desire to have my past expenses reimbursed.

    Bacula is now a fairly mature product, and to ensure its long
    term survival, I believe it is time that Bacula begins to
    stand on its own, both financially and for the development, 
    which is why we began accepting donations or project support
    in November 2005.
    <p>
    There are ways you can contribute to the Bacula
    project, some of which are: ideas, user support,
    documentation review, translation, programming and
    contributing code, testing the new releases, hosting
    services, testing machines, donating needed equipment, and
    financial support.

    Previously all but the last one (financial support) were possible.
    It is now possible for you to contribute financial aid
    the Bacula project.  All funds collected will be used to help
    further the Bacula project by covering out of pocket expenses
    incurred by the project (no salaries).  Examples are, administrative
    fees, hardware, software licenses (yes Micro$oft), and possibly a
    portion of travel/conference expenses.

    <p>
    Contributions may not be US tax deductible as Bacula is
    based in Switzerland. 
    <p>
    If you are a government or for-profit corporation and cannot
    make &quot;donations&quot;, please consider paying a (non-obligatory)
    binary license fee for any Bacula built binaries that you download.
    By making these pre-built, pre-tested binaries available, we are
    providing users who download them with an extra service, which merits
    careful consideration for making a contribution or paying a 
    &quot;license fee&quot;.
    <p>
    If you are a corporation and cannot make donations and don't want
    to pay a binary license fee, you can request an invoice for
    Bacula Project development.  Please see below for how to do this.

    <p>
    To make a contribution, please click on the donate button at
    the top of the screen, and your transaction will be secured
    and confirmed directly by PayPal.  If you contribute, or have
    any questions, please send me an email directly: kern at
    sibbald dot com.

    <p>
    If you need an invoice, I can send you one, but in order to limit my
    administrative work, I kindly request you to make a donation of at least
    $200 before requesting an invoice. To obtain one, simply email me the exact
    name to appear on the invoice as well as the mailing address, the amount
    you want to contribute, and the project you are supporting (or simply
    Bacula development).

    <p>
    The Bacula web site has a &quot;Donations Received&quot; page where
    you can have your company name, your name, and the amount (or any
    combination of those) listed. You must explicitly request to be listed. 
    Do so by sending an email to: kern at sibbald dot com after you have
    made the payment.

    <p>Although there is one link to our ISP, who we thank for providing the
    hosting service, we do not provide any links to other sites other than
    on the Professional page.
                                    
<p>
</tr>

</table>
<? require_once("inc/footer.php"); ?>
